==> ramodels-9.1.5.tar.gz: ramodels-9.1.5/ramodels/mo/__init__.py <==
#!/usr/bin/env python3
# --------------------------------------------------------------------------------------
# SPDX-FileCopyrightText: 2021 Magenta ApS <https://magenta.dk>
# SPDX-License-Identifier: MPL-2.0
# --------------------------------------------------------------------------------------
# --------------------------------------------------------------------------------------
# Imports
# --------------------------------------------------------------------------------------
from ._shared import MOBase
from ._shared import MORef
from ._shared import OpenValidity
from ._shared import Validity
from .class_ import ClassRead
from .class_ import ClassWrite
from .employee import Employee
from .employee import EmployeeRead
from .employee import EmployeeWrite
from .facet import FacetClass
from .facet import FacetRead
from .organisation import OrganisationRead
from .organisation_unit import OrganisationUnit
from .organisation_unit import OrganisationUnitRead
from .organisation_unit import OrganisationUnitWrite

# --------------------------------------------------------------------------------------
# All
# --------------------------------------------------------------------------------------

__all__ = [
    "ClassRead",
    "ClassWrite",
    "Employee",
    "EmployeeRead",
    "EmployeeWrite",
    "FacetClass",
    "FacetRead",
    "MOBase",
    "MORef",
    "OpenValidity",
    "OrganisationRead",
    "OrganisationUnit",
    "OrganisationUnitRead",
    "OrganisationUnitWrite",
    "Validity",
]

==> ramodels-11.3.2.tar.gz: ramodels-11.3.2/ramodels/mo/__init__.py <==
#!/usr/bin/env python3
# --------------------------------------------------------------------------------------
# SPDX-FileCopyrightText: 2021 Magenta ApS <https://magenta.dk>
# SPDX-License-Identifier: MPL-2.0
# --------------------------------------------------------------------------------------
# --------------------------------------------------------------------------------------
# Imports
# --------------------------------------------------------------------------------------
from ._shared import MOBase
from ._shared import MORef
from ._shared import OpenValidity
from ._shared import Validity
from .class_ import ClassRead
from .class_ import ClassWrite
from .employee import Employee
from .employee import EmployeeRead
from .employee import EmployeeWrite
from .facet import FacetRead
from .facet import FacetWrite
from .organisation import OrganisationRead
from .organisation_unit import OrganisationUnit
from .organisation_unit import OrganisationUnitRead
from .organisation_unit import OrganisationUnitWrite

# --------------------------------------------------------------------------------------
# All
# --------------------------------------------------------------------------------------

__all__ = [
    "ClassRead",
    "ClassWrite",
    "Employee",
    "EmployeeRead",
    "EmployeeWrite",
    "FacetRead",
    "FacetWrite",
    "MOBase",
    "MORef",
    "OpenValidity",
    "OrganisationRead",
    "OrganisationUnit",
    "OrganisationUnitRead",
    "OrganisationUnitWrite",
    "Validity",
]
